==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/BarTrendLineManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { CategoryTrendLineManager } from "./CategoryTrendLineManager";
import { List$1 } from "igniteui-angular-core";
import { Point_$type, markType } from "igniteui-angular-core";
import { BarTrendFitCalculator } from "./BarTrendFitCalculator";
import { TrendAverageCalculator } from "./TrendAverageCalculator";
/**
 * @hidden
 */
export let BarTrendLineManager = /*@__PURE__*/ (() => {
    class BarTrendLineManager extends CategoryTrendLineManager {
        prepareLineCore(a, b, c, d, e, f, g) {
            let h = g.d * g.c;
            let i = g.e * g.c;
            let j = new List$1(Point_$type, 0);
            if (b == 0) {
                this.a = null;
                this.d.clear();
                return;
            }
            if (this.c(b)) {
                this.d.clear();
                this.a = BarTrendFitCalculator.a(j, b, g, this.a, c.count, (k) => c.item(k), (k) => k + 1, e, (k) => f(k - 1), h + 1, i + 1);
            }
            if (this.b(b)) {
                this.a = null;
                TrendAverageCalculator.b(b, this.d, c, d);
                for (let k = g.d; k <= g.e; k += 1) {
                    let l = k * g.c;
                    if (l >= 0 && l < this.d.count) {
                        let m = e(this.d._inner[l]);
                        let n = f(l);
                        j.add({ $type: Point_$type, x: m, y: n + g.a });
                    }
                }
            }
            this.e(j, g, a);
        }
    }
    BarTrendLineManager.$t = markType(BarTrendLineManager, 'BarTrendLineManager', CategoryTrendLineManager.$);
    return BarTrendLineManager;
})();

==> igniteui-angular-charts-17.0.0-beta.0.tgz: package/esm2015/lib/BarTrendLineManager.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { CategoryTrendLineManager } from "./CategoryTrendLineManager";
import { List$1 } from "igniteui-angular-core";
import { Point_$type, markType } from "igniteui-angular-core";
import { BarTrendFitCalculator } from "./BarTrendFitCalculator";
import { TrendAverageCalculator } from "./TrendAverageCalculator";
/**
 * @hidden
 */
export let BarTrendLineManager = /*@__PURE__*/ (() => {
    class BarTrendLineManager extends CategoryTrendLineManager {
        prepareLineCore(a, b, c, d, e, f, g) {
            let h = g.f * g.e;
            let i = g.g * g.e;
            let j = new List$1(Point_$type, 0);
            if (b == 0) {
                this.a = null;
                this.d.clear();
                return;
            }
            if (this.c(b)) {
                this.d.clear();
                this.a = BarTrendFitCalculator.a(j, b, g, this.a, c.count, (k) => c.item(k), (k) => k + 1, e, (k) => f(k - 1), h + 1, i + 1);
            }
            if (this.b(b)) {
                this.a = null;
                TrendAverageCalculator.b(b, this.d, c, d);
                for (let k = g.f; k <= g.g; k += 1) {
                    let l = k * g.e;
                    if (l >= 0 && l < this.d.count) {
                        let m = e(this.d._inner[l]);
                        let n = f(l);
                        j.add({ $type: Point_$type, x: m, y: n + g.a });
                    }
                }
            }
            this.e(j, g, a);
        }
    }
    BarTrendLineManager.$t = markType(BarTrendLineManager, 'BarTrendLineManager', CategoryTrendLineManager.$);
    return BarTrendLineManager;
})();
